# Common makefile for Extensible Interpreter Design Kit using IBM compilers

XIDEK = ..\..\..

SUPPORT_DIR = $(XIDEK)\support\$(SUPPORT_EXT)
LANG_DIR =    $(XIDEK)\$(LANG)\$(LANG_EXT)
DRIVER_DIR =  $(XIDEK)\driver
AGCLIB_DIR =  $(XIDEK)\agclib1
TEST_DIR =    $(XIDEK)\test\$(LANG)

!ifndef RES
RES = r2
!endif

CC = icc

CFLAGS = -I$(SUPPORT_DIR) -I$(LANG_DIR) -I$(AGCLIB_DIR)\include -qmakedep

OBJS = demo.obj comdefs.obj bcidefs.obj astdefs.obj ast.obj\
       dxi.obj dci.obj astxi.obj astci.obj

SUPPORT_OBJS     = comdefs.obj bcidefs.obj astdefs.obj astxi.obj astci.obj
LANG_OBJS        = ast.obj dxi.obj dci.obj
DRIVER_OBJS      = demo.obj

DXI_OBJS   = demo.obj dxi.obj   comdefs.obj
DCI_OBJS   = demo.obj dci.obj   comdefs.obj bcidefs.obj
ASTXI_OBJS = demo.obj astxi.obj comdefs.obj ast.obj astdefs.obj
ASTCI_OBJS = demo.obj astci.obj comdefs.obj ast.obj astdefs.obj bcidefs.obj

AGCLIB = $(AGCLIB_DIR)\vacpp\agclib1.lib

PROGS  = dxi.exe dci.exe astxi.exe astci.exe

DX = t1.dx t2.dx t3.dx
DC = t1.dc t2.dc t3.dc
AX = t1.ax t2.ax t3.ax
AC = t1.ac t2.ac t3.ac

TESTS = $(DX) $(DC) $(AX) $(AC) $(EXT_TESTS)

# the first rule is the one you get when you type "make" by itself
all: progs tests

progs: $(PROGS)

tests: $(TESTS)

retest: clearTests $(TESTS)

dxi.exe: $(DXI_OBJS) $(AGCLIB)
	$(CC) $(CFLAGS) /Fe$@ $**

dci.exe: $(DCI_OBJS) $(AGCLIB)
	$(CC) $(CFLAGS) /Fe$@ $**

astxi.exe: $(ASTXI_OBJS) $(AGCLIB)
	$(CC) $(CFLAGS) /Fe$@ $**

astci.exe: $(ASTCI_OBJS) $(AGCLIB)
	$(CC) $(CFLAGS) /Fe$@ $**

$(AGCLIB):
	cd $(AGCLIB_DIR)\vacpp
	nmake
	cd ..\..\vacpp\$(LANG)\$(SUPPORT_EXT)

# Compile phase

#Rules for compiling
{$(SUPPORT_DIR)}.cpp.obj:
	$(CC) @<<
	  $(CFLAGS) -c $< -Fo$@
<<

{$(LANG_DIR)}.cpp.obj:
	$(CC) @<<
	  $(CFLAGS) -c $< -Fo$@
<<

{$(DRIVER_DIR)}.cpp.obj:
	$(CC) @<<
	  $(CFLAGS) -c $< -Fo$@
<<

#Parser Build Phase
.SUFFIXES: .syn

#Explicit dependencies, needed to make parser builds work
dxi.obj : $(LANG_DIR)\dxi.cpp $(LANG_DIR)\dxi.h
dci.obj : $(LANG_DIR)\dci.cpp $(LANG_DIR)\dci.h
ast.obj : $(LANG_DIR)\ast.cpp $(LANG_DIR)\ast.h

#Rules for building parsers
{$(LANG_DIR)}.syn{$(LANG_DIR)}.cpp:
	cd $(LANG_DIR)
	agcl $<
	cd ..\..\vacpp\$(LANG)\$(SUPPORT_EXT)

#Tests
.SUFFIXES: .dx .dc .ax .ac .scf

#Dependencies
t1.dx: $(TEST_DIR)\t1.scf  dxi.exe
t1.dc: $(TEST_DIR)\t1.scf  dci.exe
t1.ax: $(TEST_DIR)\t1.scf  astxi.exe
t1.ac: $(TEST_DIR)\t1.scf  astci.exe

t2.dx: $(TEST_DIR)\t2.scf  dxi.exe
t2.dc: $(TEST_DIR)\t2.scf  dci.exe
t2.ax: $(TEST_DIR)\t2.scf  astxi.exe
t2.ac: $(TEST_DIR)\t2.scf  astci.exe

t3.dx: $(TEST_DIR)\t3.scf  dxi.exe
t3.dc: $(TEST_DIR)\t3.scf  dci.exe
t3.ax: $(TEST_DIR)\t3.scf  astxi.exe
t3.ac: $(TEST_DIR)\t3.scf  astci.exe

#Locate test files

#Rules for running tests
{$(TEST_DIR)}.scf.dx:
	dxi $(TEST_DIR)\$* > $*.dx
	fc $*.dx $(TEST_DIR)\$(*B).$(RES)

{$(TEST_DIR)}.scf.dc:
	dci $(TEST_DIR)\$* > $*.dc
	fc $*.dc $(TEST_DIR)\$(*B).$(RES)

{$(TEST_DIR)}.scf.ax:
	astxi $(TEST_DIR)\$* > $*.ax
	fc $*.ax $(TEST_DIR)\$(*B).$(RES)

{$(TEST_DIR)}.scf.ac:
	astci $(TEST_DIR)\$* > $*.ac
	fc $*.ac $(TEST_DIR)\$(*B).$(RES)

# Remove object files and library file for a fresh build
# clean is the standard target name for "remove objects".
clean: clearTests
	del $(OBJS)
        del $(PROGS)

clearTests :
	del *.dx *.dc *.ax *.ac

!include depend.mk
